Learn R Programming

worldriskpollr (version 0.7.4)

wrp_search: Get aggregated data for a question in the World Risk Poll

Description

Allows you to access aggregated data for a World Risk Poll question.

Usage

wrp_search(string = "violence")

Value

data frame with World Risk Poll questions containing the search term.

Arguments

string

string, search term for the World Risk Poll questions

Examples

Run this code
wrp_search(string = "violence")

Run the code above in your browser using DataLab