powered by
Allows you to access aggregated data for a World Risk Poll question.
wrp_search(string = "violence")
data frame with World Risk Poll questions containing the search term.
string, search term for the World Risk Poll questions
Run the code above in your browser using DataLab